==> casacore_2.2.0.orig.tar.gz: casacore-2.2.0/casa/version.cc <==
//# version.cc: Get casacore version
//# Copyright (C) 2008
//# Associated Universities, Inc. Washington DC, USA.
//#
//# This library is free software; you can redistribute it and/or modify it
//# under the terms of the GNU Library General Public License as published by
//# the Free Software Foundation; either version 2 of the License, or (at your
//# option) any later version.
//#
//# This library is distributed in the hope that it will be useful, but WITHOUT
//# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
//# License for more details.
//#
//# You should have received a copy of the GNU Library General Public License
//# along with this library; if not, write to the Free Software Foundation,
//# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
//#
//# Correspondence concerning AIPS++ should be addressed as follows:
//#        Internet email: aips2-request@nrao.edu.
//#        Postal address: AIPS++ Project Office
//#                        National Radio Astronomy Observatory
//#                        520 Edgemont Road
//#                        Charlottesville, VA 22903-2475 USA
//#
//# $Id$

#include <casacore/casa/version.h>

namespace casacore { //# NAMESPACE CASACORE - BEGIN

  // Get the casacore version.
  const std::string getVersion()
  {
    static std::string version("trunk");
    return version;
  }

  // Get the version of casacore on CASA's vendor branch
  const std::string getVersionCASA()
  {
    return CASACORE_VERSION;
  }

} //# NAMESPACE CASACORE - END

==> casacore_3.5.0.orig.tar.gz: casacore-3.5.0/casa/version.cc <==
//# version.cc: Get casacore version
//# Copyright (C) 2008
//# Associated Universities, Inc. Washington DC, USA.
//#
//# This library is free software; you can redistribute it and/or modify it
//# under the terms of the GNU Library General Public License as published by
//# the Free Software Foundation; either version 2 of the License, or (at your
//# option) any later version.
//#
//# This library is distributed in the hope that it will be useful, but WITHOUT
//# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
//# License for more details.
//#
//# You should have received a copy of the GNU Library General Public License
//# along with this library; if not, write to the Free Software Foundation,
//# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
//#
//# Correspondence concerning AIPS++ should be addressed as follows:
//#        Internet email: aips2-request@nrao.edu.
//#        Postal address: AIPS++ Project Office
//#                        National Radio Astronomy Observatory
//#                        520 Edgemont Road
//#                        Charlottesville, VA 22903-2475 USA
//#
//# $Id$

#include <casacore/casa/version.h>

namespace casacore { //# NAMESPACE CASACORE - BEGIN

  // Get the casacore version.
  const char* getVersion()
  {
    return CASACORE_VERSION;
  }

  // Get the version of casacore on CASA's vendor branch
  const std::string getVersionCASA()
  {
    return CASACORE_VERSION;
  }

} //# NAMESPACE CASACORE - END
